{ config, pkgs, inputs, ... }:

{
  boot.supportedFilesystems = [ "ntfs" ];

  i18n.defaultLocale = "en_GB.UTF-8";
  i18n.extraLocaleSettings = {
    LC_ADDRESS = "en_GB.UTF-8";
    LC_IDENTIFICATION = "en_GB.UTF-8";
    LC_MEASUREMENT = "en_GB.UTF-8";
    LC_MONETARY = "en_GB.UTF-8";
    LC_NAME = "en_GB.UTF-8";
    LC_NUMERIC = "en_GB.UTF-8";
    LC_PAPER = "en_GB.UTF-8";
    LC_TELEPHONE = "en_GB.UTF-8";
    LC_TIME = "en_GB.UTF-8";
  };
  environment.variables.LC_ALL = "en_GB.UTF-8";

  time.timeZone = "Europe/London";

  users.users.tsv = {
    isNormalUser = true;
    extraGroups = [
      "wheel"
      "docker"
      "tmux"
      "davfs2"
    ];
    initialPassword = "password";
    openssh.authorizedKeys.keyFiles = [
      ../../users/tsv/authorized_keys
    ];
  };

  services.pcscd.enable = true;
  programs.gnupg.agent = {
    enable = true;
    pinentryFlavor = "curses";
  };

  nix = {
    extraOptions = "experimental-features = nix-command flakes";
    package = pkgs.nixFlakes;
    settings = {
      auto-optimise-store = true;
      trusted-users = [ "root" "tsv" "nixremote" ];
    };
    gc = {
      automatic = true;
      dates = "weekly";
      options  = "--delete-older-than 7d";
    };
  };

  hardware.bluetooth.enable = true;

  nixpkgs.config.allowUnfree = true;

  programs.ssh = {
    startAgent = true;
  };

  services.openssh = {
    enable = true;
    ports = [ 2222 2223 ];
    settings.PasswordAuthentication = false;
  };

  system.stateVersion = "22.11"; # Don't change this
}

